API Reference
=============================

dhllinalg.bla
-------------

.. automodule:: dhllinalg.bla
    :members:

    .. autoclass:: dhllinalg.bla.Vector
        :special-members: 
        :members:
        
    .. autoclass:: dhllinalg.bla.Matrix
        :special-members:
        :members:
